;; Generated package description from org-modern.el  -*- mode: lisp-data; no-byte-compile: t -*-
(define-package "org-modern" "1.11" "Modern looks for Org" '((emacs "29.1") (org "9.6") (compat "30")) :commit "55b5bbeb1eb9483d0cb43f4803615c380bf3b1ed" :authors '(("Daniel Mendler" . "mail@daniel-mendler.de")) :maintainer '("Daniel Mendler" . "mail@daniel-mendler.de") :keywords '("outlines" "hypermedia" "text") :url "https://github.com/minad/org-modern")
